import { isNil, sortBy } from 'lodash';
import React, { memo, useCallback, useMemo, useState } from 'react';
import { Text, View, } from 'react-native';
import { AppConst } from '../../constants';
import styles, { getDynamicWidth, getWidth } from './StickyTableStyles';
/**
 * This component is used to render the item of the table
 * @param {ListItemProps} props
 * @returns {React.FC<ListItemProps>}
 */
const ListItem = ({ item, index, defaultMaxWidth, listItemContainerStyle, listItemContainerProps, separatorViewStyle, separatorViewProps, columnTitleStyle, columnItemStyle, columnCommonItemStyle, columnItemContainerProps, columnItemTextStyle, columnItemTextProps, }) => {
    var _a;
    const [maxWidths, setMaxWidths] = useState([]);
    /**
     * Get the max width of the text
     */
    const width = useMemo(() => {
        var _a;
        return maxWidths
            ? (_a = sortBy(maxWidths, 'width')[(maxWidths === null || maxWidths === void 0 ? void 0 : maxWidths.length) - 1]) === null || _a === void 0 ? void 0 : _a.width
            : 0;
    }, [maxWidths]);
    /**
     * Calculate the width of the text and set it to the maxWidths array
     */
    const onTextLayout = useCallback((e, innerIndex) => {
        setMaxWidths(Array.from(new Map([
            ...maxWidths,
            {
                width: e.nativeEvent.lines[0].width + AppConst.paddingHorizontal,
                index,
                innerIndex,
            },
        ].map(widths => [widths.innerIndex, widths])).values()));
    }, [index, maxWidths]);
    return (React.createElement(View, { style: [
            getDynamicWidth(maxWidths, width),
            !isNil(defaultMaxWidth) && getWidth(defaultMaxWidth),
            listItemContainerStyle,
        ], ...listItemContainerProps }, item ? ((_a = item === null || item === void 0 ? void 0 : item.data) === null || _a === void 0 ? void 0 : _a.map((innerItem, innerIndex) => {
        return (React.createElement(React.Fragment, null,
            React.createElement(View, { key: `${innerItem}-${innerIndex}`, ...columnItemContainerProps, style: [
                    innerIndex === 0
                        ? styles.tableRowTitleView
                        : styles.tableRowItemText,
                    styles.tableRowView,
                    innerIndex === 0 ? columnTitleStyle : columnItemStyle,
                    columnCommonItemStyle,
                    !isNil(defaultMaxWidth) && getWidth(defaultMaxWidth),
                ] },
                React.createElement(Text, { numberOfLines: 1, style: [
                        columnItemTextStyle,
                        !isNil(defaultMaxWidth) &&
                            getWidth(defaultMaxWidth, AppConst.paddingHorizontal), // 32 is the padding of the text which is 16 on each side
                    ], ...columnItemTextProps, onTextLayout: (e) => {
                        onTextLayout(e, innerIndex);
                    } }, innerItem)),
            React.createElement(View, { style: [styles.separatorView, separatorViewStyle], ...separatorViewProps })));
    })) : (React.createElement(React.Fragment, null))));
};
export default memo(ListItem);
//# sourceMappingURL=ListItem.js.map