import React from 'react';
import { ScrollView, View } from 'react-native';
import Animated from 'react-native-reanimated';
import { AppConst } from '../../constants';
import ListItem from './ListItem';
import Title from './Title';
import { useStickyTable } from './hooks';
import styles from './StickyTableStyles';
/**
 * This component is used to render the sticky table
 * @param data - data to render the table
 * @param maxWidth - max width of the title
 * @param minWidth - min width of the title
 * @param removeProperty - property to remove from the title
 * @returns -React Element
 */
const StickyTable = ({ data, maxWidth = AppConst.maxWidth, minWidth = AppConst.minWidth, rowTitleProps, scrollViewProps, containerStyle, containerProps, flatListProps, tableItemProps, }) => {
    var _a;
    const { flatListRef, onScroll, animatedWidthStyle, translateFirstTextStyle, flexValue, setFirstWordWidths, firstWordWidths, translationX, } = useStickyTable({ maxWidth, minWidth });
    return (React.createElement(ScrollView, { style: styles.screen, ...scrollViewProps },
        React.createElement(View, { style: [styles.container, containerStyle], ...containerProps },
            React.createElement(View, null, (_a = data === null || data === void 0 ? void 0 : data.titleData) === null || _a === void 0 ? void 0 : _a.map((item, index) => {
                return (React.createElement(Title, { key: `${index}-${item}`, ...{
                        item,
                        index,
                        animatedWidthStyle,
                        translateFirstTextStyle,
                        setFirstWordWidths,
                        firstWordWidths,
                        maxWidth,
                        minWidth,
                        translationX,
                        flexValue,
                    }, ...rowTitleProps }));
            })),
            React.createElement(Animated.FlatList, { ref: flatListRef, renderItem: ({ item, index, }) => {
                    return (React.createElement(ListItem, { item: item, index: index, ...((item === null || item === void 0 ? void 0 : item.maxWidth) && { defaultMaxWidth: item === null || item === void 0 ? void 0 : item.maxWidth }), ...tableItemProps }));
                }, keyExtractor: (_item, index) => index.toString(), showsHorizontalScrollIndicator: false, ...flatListProps, data: data === null || data === void 0 ? void 0 : data.tableData, horizontal: true, nestedScrollEnabled: true, bounces: false, overScrollMode: 'never', onScroll: onScroll }))));
};
export default StickyTable;
//# sourceMappingURL=StickyTable.js.map