import { isEmpty } from 'lodash';
import React from 'react';
import { View, } from 'react-native';
import Animated from 'react-native-reanimated';
import useTitle from './hooks/useTitle';
import styles, { getRestSentenceStyle, setWidthStyle, } from './StickyTableStyles';
/**
 * This component is used to render the title of the table
 * @param {TitleProps} props
 * @returns {React.FC<TitleProps>}
 */
const Title = ({ item, index, animatedWidthStyle, translateFirstTextStyle, setFirstWordWidths, firstWordWidths, maxWidth = 132, minWidth = 104, translationX, flexValue, removeProperty = '', titleBackgroundColor, firstIndexContainerStyle, containerStyle, otherIndexContainerStyle, containerProps, separatorViewStyle, firstWordContainerStyle, firstWordTextProps, restSentenceContainerStyle, restSentenceTextProps, firstWordContainerProps, restSentenceContainerProps, rowTitleSeparatorViewStyle, rowTitleSeparatorViewProps, }) => {
    const { firstWord, restSentence, shouldRemove, translateLastTextStyle, onTextLayout, } = useTitle({
        item,
        removeProperty,
        translationX,
        index,
        firstWordWidths,
        maxWidth,
        minWidth,
        flexValue,
        setFirstWordWidths,
    });
    return (React.createElement(React.Fragment, null,
        React.createElement(Animated.View, { style: [
                index === 0 ? styles.tableRowTitleView : styles.tableRowViewTitle,
                setWidthStyle(maxWidth),
                animatedWidthStyle,
                !isEmpty(titleBackgroundColor) && {
                    backgroundColor: titleBackgroundColor,
                },
                index === 0 ? firstIndexContainerStyle : otherIndexContainerStyle,
                containerStyle,
            ], key: index, ...containerProps },
            React.createElement(Animated.View, { style: [
                    index !== 0 ? shouldRemove && translateFirstTextStyle : {},
                    firstWordContainerStyle,
                ], ...firstWordContainerProps },
                React.createElement(Animated.Text, { numberOfLines: 1, ...firstWordTextProps, onTextLayout: (e) => {
                        onTextLayout(e);
                    } }, `${firstWord} `)),
            React.createElement(Animated.View, { style: [
                    shouldRemove ? translateLastTextStyle : {},
                    index !== 0 && styles.restSentenceBackgroundColor,
                    getRestSentenceStyle(shouldRemove, flexValue),
                    !isEmpty(titleBackgroundColor) && {
                        backgroundColor: titleBackgroundColor,
                    },
                    restSentenceContainerStyle,
                ], ...restSentenceContainerProps },
                React.createElement(Animated.Text, { numberOfLines: 1, ellipsizeMode: "tail", ...restSentenceTextProps }, restSentence)),
            index !== 0 && (React.createElement(View, { style: [styles.rowTitleSeparatorView, rowTitleSeparatorViewStyle], ...rowTitleSeparatorViewProps }))),
        React.createElement(View, { style: [
                styles.separatorContainer,
                !isEmpty(titleBackgroundColor) && {
                    backgroundColor: titleBackgroundColor,
                },
            ] },
            React.createElement(View, { style: [styles.separatorView, separatorViewStyle] }))));
};
export default Title;
//# sourceMappingURL=Title.js.map