/**
 * Get the width and height of the device screen.
 * @returns {ScaledSize} - the width and height of the device screen.
 */
declare let width: number, height: number;
/**
 * Converts provided width to based on provided guideline size width.
 * @param  {number} size The screen's width that UI element should cover
 * @return {number} The calculated scale depending on current device's screen width.
 */
declare const horizontalScale: (size: number) => number;
/**
 * Converts provided height to based on provided guideline size height.
 * @param  {number} size The screen's height that UI element should cover
 * @return {number} The calculated vertical scale depending on current device's screen height.
 */
declare const verticalScale: (size: number) => number;
/**
 * Converts provided size to based on provided guideline size width.
 * @param  {number} size - The size of the font you want to scale
 * @param {number} [factor=0.5] - The amount of scaling to apply to font sizes. Defaults to 0.5.
 * @return {number} The calculated moderate scale depending on current device's screen width.
 */
declare const moderateScale: (size: number, factor?: number) => number;
/**
 * A type that contains the global metrics for the current device.
 * @typedef {Object} GlobalMetricsType - A type that contains the global metrics for the current device.
 * @property {boolean} isAndroid - Whether the current device is an Android device.
 */
interface GlobalMetricsType {
    isAndroid: boolean;
    isIos: boolean;
    isPad: boolean;
    isTV: boolean;
    isWeb: boolean;
}
/**
 * A type that contains the global metrics for the app.
 * @type {GlobalMetricsType}
 */
declare const globalMetrics: GlobalMetricsType;
export { globalMetrics, horizontalScale, verticalScale, moderateScale, width, height, };
