import { Dimensions, Platform } from 'react-native';
/**
 * Get the width and height of the device screen.
 * @returns {ScaledSize} - the width and height of the device screen.
 */
let { width, height } = Dimensions.get('window');
if (width > height) {
    [width, height] = [height, width];
}
//Guideline sizes are based on standard ~5" screen mobile device
const guidelineBaseWidth = 375;
const guidelineBaseHeight = 812;
/**
 * Converts provided width to based on provided guideline size width.
 * @param  {number} size The screen's width that UI element should cover
 * @return {number} The calculated scale depending on current device's screen width.
 */
const horizontalScale = (size) => (width / guidelineBaseWidth) * size;
/**
 * Converts provided height to based on provided guideline size height.
 * @param  {number} size The screen's height that UI element should cover
 * @return {number} The calculated vertical scale depending on current device's screen height.
 */
const verticalScale = (size) => (height / guidelineBaseHeight) * size;
/**
 * Converts provided size to based on provided guideline size width.
 * @param  {number} size - The size of the font you want to scale
 * @param {number} [factor=0.5] - The amount of scaling to apply to font sizes. Defaults to 0.5.
 * @return {number} The calculated moderate scale depending on current device's screen width.
 */
const moderateScale = (size, factor = 0.5) => size + (horizontalScale(size) - size) * factor;
/**
 * A type that contains the global metrics for the app.
 * @type {GlobalMetricsType}
 */
const globalMetrics = {
    isAndroid: Platform.OS === 'android',
    isIos: Platform.OS === 'ios',
    isPad: Platform.OS === 'ios' && Platform.isPad,
    isTV: Platform.isTV,
    isWeb: Platform.OS === 'web',
};
export { globalMetrics, horizontalScale, verticalScale, moderateScale, width, height, };
//# sourceMappingURL=Metrics.js.map